@@ -24,40 +24,53 @@ from sanic_jwt import Authentication, utils
 from sanic_jwt.authentication import claim_label
 
 
-def _get_kdf(salt: str):
-
-    @lru_cache()
-    def _get_salt(_salt) -> bytes:
-        if _salt:
-            return _salt.encode("UTF-8")
-        else:
-            return b''
+def _get_kdf(salt: bytes):
 
     return PBKDF2HMAC(
         algorithm=hashes.SHA256(),
         length=32,
-        salt=_get_salt(salt),
+        salt=salt or b'',
         iterations=100000,
         backend=default_backend())
 
 
-@lru_cache(100)
-def fernet_crypt(text: str or bytes, password: str, salt: str) -> bytes:
-    kdf = _get_kdf(salt)
+@lru_cache(200)
+def decode_util(text: str or bytes) -> bytes:
 
-    f = Fernet(base64.urlsafe_b64encode(kdf.derive(bytes(password, "utf-8"))))
+    try:
+        _text = text.encode("UTF-8")
+    except AttributeError:
+        _text = text
 
-    return f.encrypt(bytes(text, "utf-8"))
+    return _text
 
 
 @lru_cache(100)
-def fernet_decrypt(text: bytes, password: str, salt: str) -> bytes:
-    kdf = _get_kdf(salt)
+def fernet_crypt(text: str, password: str, salt: str = None) -> bytes:
+
+    _salt = decode_util(salt)
+    _text = decode_util(text)
+    _password = decode_util(password)
+
+    kdf = _get_kdf(_salt)
+
+    f = Fernet(base64.urlsafe_b64encode(kdf.derive(_password)))
+
+    return f.encrypt(_text)
+
+
+@lru_cache(100)
+def fernet_decrypt(text: str, password: str, salt: str = None) -> bytes:
+    _salt = decode_util(salt)
+    _text = decode_util(text)
+    _password = decode_util(password)
+
+    kdf = _get_kdf(_salt)
 
     f = Fernet(
-        base64.urlsafe_b64encode(kdf.derive(bytes(password, "utf-8"))))
+        base64.urlsafe_b64encode(kdf.derive(_password)))
 
-    return f.decrypt(text)
+    return f.decrypt(_text)
 
 
 class PyJWTPayloadEncrypt(PyJWT):
